<?php 

/**
 * About US Template
 * message section
 *
 * This is the template for the content of message section
 *
 * @package Theme Palace
 * @subpackage Elead Pro
 * @since Elead Pro 1.0
 */
if ( ! function_exists( 'elead_pro_add_about_message_section' ) ) :
    /**
    * Add message section
    *
    *@since Elead Pro 1.0
    */
    function elead_pro_add_about_message_section() {
        $options = elead_pro_get_theme_options();

        // Check if message is enabled
        $enable_about_message = $options['message_enable'];

        if ( true !== $enable_about_message ) {
            return false;
        }

        // Get message section details
        $section_details = array();
        $section_details = apply_filters( 'elead_pro_filter_about_message_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }
        // Render message section now.
        elead_pro_render_about_message_section( $section_details );
    }
endif;
add_action( 'elead_pro_about_template_content', 'elead_pro_add_about_message_section', 10 );


if ( ! function_exists( 'elead_pro_get_about_message_section_details' ) ) :
    /**
    * message section details.
    *
    * @since Elead Pro 1.0
    * @param array $input message section details.
    */
    function elead_pro_get_about_message_section_details( $input ) {
        $options = elead_pro_get_theme_options();

        // message type
        $about_message_content_type  = $options['message_content_type'];

        $content = array();
        switch ( $about_message_content_type ) {

            case 'post':
                $post_id = '';
                
                if ( ! empty( $options['message_content_post'] ) )
                    $post_id = $options['message_content_post'];

                // Bail if no valid pages are selected.
                if ( empty( $post_id ) ) {
                    return $input;
                }
                $img_array = null;
                if ( has_post_thumbnail( $post_id ) ) {
                    $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), 'large' );
                } else {
                    $img_array[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-1920x1080.jpg';
                }
                if ( isset( $img_array ) ) {
                    $content[0]['img_array'] = $img_array;
                }
                $content[0]['title']        = get_the_title( $post_id );
                $content[0]['url']          = get_the_permalink( $post_id );
                $content[0]['sub_title']    = ! empty( $options['message_sub_title'] ) ? $options['message_sub_title'] : esc_html__( 'The Principle','elead-pro' );
                $content[0]['excerpt']      = get_post_field( 'post_excerpt', $post_id );
                
          	break;

            case 'page':
                $post_id = '';
                
                if ( ! empty( $options['message_content_page'] ) )
                    $post_id = $options['message_content_page'];

                // Bail if no valid pages are selected.
                if ( empty( $post_id ) ) {
                    return $input;
                }
                $img_array = null;
                if ( has_post_thumbnail( $post_id ) ) {
                    $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), 'large' );
                } else {
                    $img_array[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-1920x1080.jpg';
                }
                if ( isset( $img_array ) ) {
                    $content[0]['img_array'] = $img_array;
                }
                $content[0]['title']        = get_the_title( $post_id );
                $content[0]['url']          = get_the_permalink( $post_id );
                $content[0]['sub_title']    = ! empty( $options['message_sub_title'] ) ? $options['message_sub_title'] : esc_html__( 'The Principle','elead-pro' );
                $content[0]['excerpt']      = get_post_field( 'post_excerpt', $post_id );
                
            break;

            case 'custom':
                $content[0]['title']        = ! empty( $options['message_title'] ) ? $options['message_title'] : esc_html__( 'Linda Anderson','elead-pro' );
                $content[0]['url']          = ! empty( $options['message_link'] ) ? $options['message_link'] : esc_html__( '#','elead-pro' );
                $content[0]['sub_title']    = ! empty( $options['message_sub_title'] ) ? $options['message_sub_title'] : esc_html__( 'The Principle','elead-pro' );
                $content[0]['excerpt']      = ! empty( $options['message_description'] ) ? $options['message_description'] : esc_html__( 'Aliquam sodales cursus nibh sed interdum. Mauris volutpat condimentum sapien id maximus. Duisa aliquam sed est sit amet varius. Ut luctus, libero id maximus auctor, ex magna molestie est, eu pellentesque erat eros eget dui. Curabitur nec volutpat ex, hendrerit convallis arcu, curabitur varius consectetur.','elead-pro' );
                $content[0]['img_array'][0]    = ! empty( $options['message_image'] ) ? $options['message_image'] : get_template_directory_uri() . '/assets/uploads/bg-principals.jpg';
                
            break;


        }

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// message section content details.
add_filter( 'elead_pro_filter_about_message_section_details', 'elead_pro_get_about_message_section_details' );


if ( ! function_exists( 'elead_pro_render_about_message_section' ) ) :
    /**
    * Start message section
    *
    * @return string message content
    * @since Elead Pro 1.0
    *
    */
    function elead_pro_render_about_message_section( $content_details ) {
        $options = elead_pro_get_theme_options();
        $message_section_title  = ! empty( $options['message_section_title'] ) ? $options['message_section_title'] : esc_html__( 'We provide best education in better way.', 'elead-pro' );
    
        if ( empty( $content_details ) ) {
            return;
        }

        foreach ( $content_details as $content_detail ) : ?>
            <section id="principals-message" class="col-2 clear">
                <div class="hentry">
                    <div class="quatation">
                        <div class="page-section">
                            <?php if( ! empty( $message_section_title ) ) : ?>
                                <header class="entry-header">
                                    <h2 class="entry-title"><?php echo esc_html( $message_section_title ); ?></h2>
                                </header><!-- .entry-header -->
                            <?php endif; ?>
                            <div class="entry-content">
                                <?php if( ! empty( $content_detail['excerpt'] ) ) : ?>
                                    <p><?php echo esc_html( $content_detail['excerpt'] ); ?></p>
                                <?php endif; ?>
                                <div class="seperator"></div>
                                <h5><a href="<?php echo esc_url( $content_detail['url'] ); ?>"><?php echo esc_html( $content_detail['title'] ); ?></a></h5>
                                <span><?php echo esc_html( $content_detail['sub_title'] ); ?></span>
                            </div><!-- .entry-content -->
                        </div><!-- .page-section -->
                    </div><!-- .quatation -->
                </div><!-- .hentry -->
                <div class="hentry">
                    <div class="featured-image" style="background-image: url('<?php echo esc_url( $content_detail['img_array'][0] ); ?>');"></div>
                </div><!-- .hentry -->
            </section><!-- #principals-message -->
        <?php endforeach; 
    }
endif;


/**
 * About US Template
 * features section
 *
 * This is the template for the content of features section
 *
 * @package Theme Palace
 * @subpackage Elead Pro
 * @since Elead Pro 1.0
 */
if ( ! function_exists( 'elead_pro_add_about_features_section' ) ) :
    /**
    * Add features section
    *
    *@since Elead Pro 1.0
    */
    function elead_pro_add_about_features_section() {
        $options = elead_pro_get_theme_options();

        // Check if features is enabled
        $enable_about_features = $options['features_enable'];

        if ( true !== $enable_about_features ) {
            return false;
        }

        // Get features section details
        $section_details = array();
        $section_details = apply_filters( 'elead_pro_filter_about_features_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }
        // Render features section now.
        elead_pro_render_about_features_section( $section_details );
    }
endif;
add_action( 'elead_pro_about_template_content', 'elead_pro_add_about_features_section', 20 );


if ( ! function_exists( 'elead_pro_get_about_features_section_details' ) ) :
    /**
    * features section details.
    *
    * @since Elead Pro 1.0
    * @param array $input features section details.
    */
    function elead_pro_get_about_features_section_details( $input ) {
        $options = elead_pro_get_theme_options();

        // features type
        $about_features_content_type  = $options['features_content_type'];

        $content = array();
        switch ( $about_features_content_type ) {

            case 'post':
                $ids = array();
                
                if ( ! empty( $options['features_content_post'] ) )
                    $ids = ( array ) $options['features_content_post'];

                // Bail if no valid pages are selected.
                if ( empty( $ids ) ) {
                    return $input;
                }

                $args = array(
                    'no_found_rows'  => true,
                    'orderby'        => 'post__in',
                    'post_type'      => 'post',
                    'post__in'       => $ids,
                    'posts_per_page' => 3,
                );  
                
            break;

            case 'page':
                $ids = array();

                for ( $i = 1; $i <= 3; $i++ ) {
                    $id = null;
                    if ( isset( $options[ 'features_content_page_'.$i ] ) ) {
                        $id = $options[ 'features_content_page_'.$i ];
                    }
                    if ( ! empty( $id ) ) {
                        $ids[] = absint( $id );
                    }
                }

                // Bail if no valid pages are selected.
                if ( empty( $ids ) ) {
                    return $input;
                }

                $args = array(
                    'no_found_rows'  => true,
                    'orderby'        => 'post__in',
                    'post_type'      => 'page',
                    'post__in'       => $ids,
                );
            break;

            case 'custom':
                for ( $i = 1; $i <= 3; $i++ ) :

                    $content[$i]['title'] = ! empty( $options['features_custom_title_'.$i ] ) ? $options['features_custom_title_'.$i] : esc_html__( 'Quality Education','elead-pro' );       
                    $content[$i]['excerpt'] = ! empty( $options['features_custom_excerpt_'.$i ] ) ? $options['features_custom_excerpt_'.$i] : esc_html__( 'Proin efficitur velit et cursus vulputate. Aenean ele mentum sodales libero vitae auctor. Pellentesque tellus nisl, porta eu feugiat et, eleifend ut mi','elead-pro' );
                    $content[$i]['url'] = ! empty( $options['features_custom_url_'.$i ] ) ? $options['features_custom_url_'.$i] : esc_html__( '#','elead-pro' );
                    $content[$i]['icon'] = ! empty( $options['features_custom_icon_'.$i ] ) ? $options['features_custom_icon_'.$i] : 'fa-user';
                endfor;
            
            break;

        }
        if ( 'custom' != $about_features_content_type ) {
            $posts = get_posts( $args );
            if ( ! empty( $posts ) ) :
                $i = 1;
                foreach ( $posts as $post ) :
                    $post_id = $post->ID;
                    $icon = get_post_meta( $post_id, 'elead-pro-post-icon', true );
                    $content[$i]['id']       = $post_id;
                    $content[$i]['title']    = get_the_title( $post_id );
                    $content[$i]['url']      = get_the_permalink( $post_id );
                    $content[$i]['excerpt']  = elead_pro_trim_content( 20, $post );
                    $content[$i]['icon']     = ! empty( $icon ) ? $icon : 'fa-tint' ;
                    $i++;
                endforeach;
            endif;
        }

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// features section content details.
add_filter( 'elead_pro_filter_about_features_section_details', 'elead_pro_get_about_features_section_details' );


if ( ! function_exists( 'elead_pro_render_about_features_section' ) ) :
    /**
    * Start features section
    *
    * @return string features content
    * @since Elead Pro 1.0
    *
    */
    function elead_pro_render_about_features_section( $content_details ) {
        $options = elead_pro_get_theme_options();
        $title = ! empty( $options['features_title'] ) ? $options['features_title'] : '';
        $description = ! empty( $options['features_description'] ) ? $options['features_description'] : '';
    
        if ( empty( $content_details ) ) {
            return;
        }

        $i = 1;
        ?>
        <section id="about-service" class="col-3 page-section" style="background-image: url('<?php echo get_template_directory_uri() . '/assets/uploads/promotion.jpg'; ?>'); background-position: 0% 60px;" data-stellar-background-ratio="0.5" data-stellar-vertical-offset="0">
            <div class="wrapper">
                <div class="services-context col-3 align-center">
                    <?php foreach ( $content_details as $content_detail ) :  ?>
                        <div class="hentry">
                            <div class="service">
                                <a href="<?php echo ! empty( $content_detail['url'] ) ? esc_url( $content_detail['url'] ) : '#'; ?>">
                                    <i class="fa <?php echo esc_html( $content_detail['icon'] ); ?>"></i>
                                </a>
                                <h5 class="featured-title"><a href="<?php echo esc_url( $content_detail['url'] ); ?>"><?php echo esc_html( $content_detail['title'] ) ?></a></h5>
                                <p><?php echo esc_html( $content_detail['excerpt'] ); ?></p>
                            </div><!-- .service -->
                        </div><!-- .hentry -->
                    <?php endforeach; ?>
                </div><!-- .services-context -->
            </div><!-- .wrapper -->
        </section><!-- #our-services -->
    <?php }
endif;

/**
 * About US Template 
 * Team section
 *
 * This is the template for the content of team section
 *
 * @package Theme Palace
 * @subpackage Elead Pro
 * @since Elead Pro 1.0
 */
if ( ! function_exists( 'elead_pro_add_aboutteam_section' ) ) :
    /**
    * Add team section
    *
    *@since Elead Pro 1.0
    */
    function elead_pro_add_aboutteam_section() {
        $options = elead_pro_get_theme_options();

        // Check if team is enabled
        $enable_aboutteam = $options['aboutteam_enable'];

        if ( true !== $enable_aboutteam ) {
            return false;
        }

        // Get team section details
        $section_details = array();
        $section_details = apply_filters( 'elead_pro_filter_aboutteam_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }
        // Render team section now.
        elead_pro_render_aboutteam_section( $section_details );
    }
endif;
add_action( 'elead_pro_about_template_content', 'elead_pro_add_aboutteam_section', 30 );


if ( ! function_exists( 'elead_pro_get_aboutteam_section_details' ) ) :
    /**
    * about team section details.
    *
    * @since Elead Pro 1.0
    * @param array $input team section details.
    */
    function elead_pro_get_aboutteam_section_details( $input ) {
        $options = elead_pro_get_theme_options();

        // team type
        $aboutteam_content_type  = $options['aboutteam_content_type'];

        switch ( $aboutteam_content_type ) { 

            case 'category':
                $cat_id = '';
                if ( ! empty( $options['aboutteam_content_category'] ) ) {
                    $cat_id = $options['aboutteam_content_category'];
                }

                // Bail if no valid pages are selected.
                if ( empty( $cat_id ) ) {
                    return $input;
                }else{
                    $cat_id = absint( $cat_id );
                }

                $args = array(
                    'no_found_rows'  => true,
                    'cat'            => $cat_id,
                    'post_type'      => 'post',
                    'posts_per_page' => 4,
                );
            break;

            case 'post':
                $ids = array();
                
                if ( ! empty( $options['aboutteam_content_post'] ) )
                    $ids = ( array ) $options['aboutteam_content_post'];

                // Bail if no valid pages are selected.
                if ( empty( $ids ) ) {
                    return $input;
                }

                $args = array(
                    'no_found_rows'  => true,
                    'orderby'        => 'post__in',
                    'post_type'      => 'post',
                    'post__in'       => $ids,
                    'posts_per_page' => 4,
                );                             
            break;

            case 'team':
                $ids = array();
                
                if ( ! empty( $options['aboutteam_content_team'] ) )
                    $ids = ( array ) $options['aboutteam_content_team'];

                // Bail if no valid pages are selected.
                if ( empty( $ids ) ) {
                    return $input;
                }

                $args = array(
                    'no_found_rows'  => true,
                    'orderby'        => 'post__in',
                    'post_type'      => 'tp-team',
                    'post__in'       => $ids,
                    'posts_per_page' => 4,
                );                             
            break;

            case 'team-category':
                $cat_id = '';
                if ( ! empty( $options['aboutteam_content_team_category'] ) ) {
                    $cat_id = $options['aboutteam_content_team_category'];
                }

                // Bail if no valid pages are selected.
                if ( empty( $cat_id ) ) {
                    return $input;
                }else{
                    $cat_id = absint( $cat_id );
                }

                $args = array(
                    'post_type'         => 'tp-team',
                    'posts_per_page'    => 4,
                    'tax_query'         => array(
                        array(
                            'taxonomy'  => 'tp-team-category',
                            'field'     => 'id',
                            'terms'     => $cat_id
                        )
                    )
                );
                
            break;

            case 'custom':
                for ( $i = 1; $i <= 4; $i++ ) :

                    $content[$i]['title'] = ! empty( $options['aboutteam_custom_title_'.$i ] ) ? $options['aboutteam_custom_title_'.$i] : esc_html__( 'Ricky Ortega','elead-pro' );        
                    $content[$i]['subtitle'] = ! empty( $options['aboutteam_custom_subtitle_'.$i ] ) ? $options['aboutteam_custom_subtitle_'.$i] : esc_html__( 'Art Teacher','elead-pro' );        
                    $content[$i]['img_array'][0] = ! empty( $options['aboutteam_custom_image_'.$i ] ) ? $options['aboutteam_custom_image_'.$i] : get_template_directory_uri() . '/assets/uploads/professional-01.jpg';
                    $content[$i]['img_array'][1] = 400;
                    $content[$i]['img_array'][2] = 400;        
                    $content[$i]['url'] = ! empty( $options['aboutteam_member_custom_url_'.$i ] ) ? $options['aboutteam_member_custom_url_'.$i] : esc_html__( '#','elead-pro' );        
                endfor;
            break;

        } 

        if ( 'custom' != $aboutteam_content_type ) {
            $posts = get_posts( $args );
            if ( ! empty( $posts ) ) :
                $i = 1;
                foreach ( $posts as $post ) :
                    $post_id = $post->ID;
                    $img_array = array();
                    if ( has_post_thumbnail( $post_id ) ) {
                        $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post_id ), 'elead-pro-medium' );
                    } else {
                        $img_array[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-500x500.jpg';
                        $img_array[1] =  400;
                        $img_array[2] =  400;
                    }

                    if ( isset( $img_array ) ) {
                        $content[$i]['img_array'] = $img_array;
                    }
                    $content[$i]['id']      = $post_id;
                    $content[$i]['title']   = get_the_title( $post_id );
                    $content[$i]['url']     = get_the_permalink( $post_id );
                    $i++;
                endforeach;
            endif;
        }

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// team section content details.
add_filter( 'elead_pro_filter_aboutteam_section_details', 'elead_pro_get_aboutteam_section_details' );


if ( ! function_exists( 'elead_pro_render_aboutteam_section' ) ) :
    /**
    * Start about team section
    *
    * @return string about team content
    * @since Elead Pro 1.0
    *
    */
    function elead_pro_render_aboutteam_section( $content_details ) {
        $options    = elead_pro_get_theme_options();
        $aboutteam_content_type  = $options['aboutteam_content_type'];
        $aboutteam_title      = ! empty( $options['aboutteam_section_title'] ) ? $options['aboutteam_section_title'] : '';
        $aboutteam_subtitle   = ! empty( $options['aboutteam_section_subtitle']  ) ? $options['aboutteam_section_subtitle']  : '';
        $aboutteam_excerpt    = ! empty( $options['aboutteam_section_excerpt']   ) ? $options['aboutteam_section_excerpt']   : '';
        $aboutbtn_label = ! empty( $options['aboutteam_custom_btn_label']   ) ? $options['aboutteam_custom_btn_label']   : '';
        $aboutbtn_url = ! empty( $options['aboutteam_custom_btn_url']   ) ? $options['aboutteam_custom_btn_url']   : '#';

        $category_link  = '';
        $cat_name       = '';
        if ( $aboutteam_content_type == 'category' ) {
            $category_link  = get_category_link( $options['aboutteam_content_category'] );
            $cat_name       = get_the_category_by_ID( $options['aboutteam_content_category'] );
        } elseif ( $aboutteam_content_type == 'team-category' ) {
            $category_link  = get_term_link( $options['aboutteam_content_team_category' ], 'tp-team-category' );
            $term           = get_term_by('id', $options['aboutteam_content_team_category' ] , 'tp-team-category' );
            $cat_name       = $term->name;
        } elseif ( $aboutteam_content_type == 'demo' ) {
            $category_link  = '#';
            $cat_name       = esc_html__( 'Teachers', 'elead-pro' );
        }

        if ( empty( $content_details ) ) {
            return;
        }
        ?>
        <section id="professional" class="page-section col-3">
            <div class="wrapper">
                <div class="row">
                    <div class="hentry">
                        <div class="professional-teacher align-left">
                            <header class="entry-header">
                                <?php if ( ! empty( $aboutteam_title ) ) : ?>
                                    <h2 class="entry-title"><?php echo esc_html( $aboutteam_title ); ?></h2>
                                <?php endif; 
                                if ( ! empty( $aboutteam_subtitle ) ) : ?>
                                    <p class="entry-title-desc"><?php echo esc_html( $aboutteam_subtitle ); ?></p>
                                <?php endif; ?>
                            </header>
                            <?php if ( ! empty( $aboutteam_excerpt ) ) : ?>
                                <div class="entry-content">
                                    <p><?php echo esc_html( $aboutteam_excerpt ); ?></p>
                                </div><!-- .entry-content -->
                            <?php endif; ?>
                        </div><!-- .professional-teacher -->
                    </div><!-- .hentry -->

                    <?php foreach ( $content_details as $content_detail ) : ?>
                        <div class="hentry">
                            <div class="professional-teacher">
                                <?php if( ! empty( $content_detail['img_array'][0] ) ) { ?>
                                    <a href="<?php echo ! empty( $content_detail['url'] ) ? esc_url( $content_detail['url'] ) : '#'; ?>"><img src="<?php echo esc_url( $content_detail['img_array'][0] ); ?>" width="<?php echo esc_attr( $content_detail['img_array'][1] ); ?>" height="<?php echo esc_attr( $content_detail['img_array'][2] ); ?>"></a>
                                <?php } ?>
                                <div class="hover-content">
                                    <?php if( ! empty( $content_detail['title'] ) ) { ?>
                                        <h5><a href="<?php echo ! empty( $content_detail['url'] ) ? esc_url( $content_detail['url'] ) : '#'; ?>"><?php echo esc_html( $content_detail['title'] ); ?></a></h5>
                                    <?php } ?>
                                    <?php if ( in_array( $aboutteam_content_type, array( 'team', 'team-category' ) ) ) : 
                                        if ( has_action( 'tp_team_designation_action' ) ) :
                                            do_action( 'tp_team_designation_action', $content_detail['id'] );
                                        endif;
                                    elseif ( $aboutteam_content_type == 'demo' ) : ?>
                                        <span class="tp-team-designation"><?php esc_html_e( 'Art Teacher', 'elead-pro' ); ?></span>
                                    <?php elseif ( $aboutteam_content_type == 'custom' && ! empty( $content_detail['subtitle'] ) ) : ?>
                                        <span class="tp-team-designation"><?php echo esc_html( $content_detail['subtitle'] ); ?></span>
                                    <?php endif; ?>
                                </div><!-- .hover-content -->
                            </div><!-- .professional-teacher -->
                        </div><!-- .hentry -->
                    <?php endforeach; ?>
                </div><!-- .row -->
                <?php if ( in_array( $aboutteam_content_type, array( 'team', 'custom', 'post' ) ) ) :    
                    if ( ! empty( $aboutbtn_label ) ) : ?>
                        <div class="align-center">
                            <a href="<?php echo esc_url( $aboutbtn_url ); ?>" class="btn btn-transparent"><?php echo esc_html( $aboutbtn_label ); ?></a>
                        </div><!-- .align-center -->
                    <?php endif;
                else :
                    if ( ! empty( $category_link ) ) { ?>
                    <div class="align-center">
                        <a href="<?php echo esc_url( $category_link ); ?>" class="btn btn-transparent"><?php printf( '%s ' . esc_html( $cat_name ), esc_html__( 'View all', 'elead-pro' ) ); ?></a>
                    </div>  
                <?php  } endif; ?>
            </div><!-- .wrapper -->
        </section><!-- #professional -->
    <?php }
endif;
