<?php
/**
 * Contact Us Template options
 *
 * @package Theme Palace
 * @subpackage Elead Pro
 * @since Elead Pro 1.0
 */

// Add panel for Contact Us Template
$wp_customize->add_panel( 'elead_pro_contact_us_panel' , array(
    'title'      => esc_html__( 'Contact Us Template','elead-pro' ),
    'description'=> esc_html__( 'Contact Us Template Options', 'elead-pro' ),
    'priority'   => 150,
) );

/*
 * Contact form Naming Section
 */
$wp_customize->add_section( 'elead_pro_contact_form_name_section', array(
    'title'             => esc_html__( 'Contact Us Name Section','elead-pro' ),
    'description'       => esc_html__( 'Contact Us Name Section Options.', 'elead-pro' ),
    'panel'             => 'elead_pro_contact_us_panel',
) );

// Add title in naming section.
$wp_customize->add_setting( 'elead_pro_theme_options[contact_us_title]', array(
    'sanitize_callback' => 'sanitize_text_field',
    'default'           => $options['contact_us_title'],
) );

$wp_customize->add_control( 'elead_pro_theme_options[contact_us_title]', array(
    'label'             => esc_html__( 'Name Section Title', 'elead-pro' ),
    'description'       => esc_html__( 'Input Place For Title', 'elead-pro' ),
    'section'           => 'elead_pro_contact_form_name_section',
    'type'              => 'text',
) );

// Add subtitle in naming section.
$wp_customize->add_setting( 'elead_pro_theme_options[contact_us_subtitle]', array(
    'sanitize_callback' => 'sanitize_text_field',
    'default'           => $options['contact_us_subtitle'],
) );

$wp_customize->add_control( 'elead_pro_theme_options[contact_us_subtitle]', array(
    'label'             => esc_html__( 'Name Section SubTitle', 'elead-pro' ),
    'description'       => esc_html__( 'Input Place For SubTitle', 'elead-pro' ),
    'section'           => 'elead_pro_contact_form_name_section',
    'type'              => 'text',
) );

/*
 * Additional Info Section
 */
$wp_customize->add_section( 'elead_pro_contact_additional_info_section', array(
    'title'             => esc_html__( 'Contact Additional Info','elead-pro' ),
    'description'       => esc_html__( 'Contact Additional Info Options.', 'elead-pro' ),
    'panel'             => 'elead_pro_contact_us_panel',
) );

// Add address info.
$wp_customize->add_setting( 'elead_pro_theme_options[contact_us_address]', array(
    'default'           => $options['contact_us_address'],
    'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'elead_pro_theme_options[contact_us_address]', array(
    'label'             => esc_html__( 'Address Info', 'elead-pro' ),
    'section'           => 'elead_pro_contact_additional_info_section',
    'type'              => 'text',
) );

// Add phone info.
$wp_customize->add_setting( 'elead_pro_theme_options[contact_us_phone]', array(
    'default'           => $options['contact_us_phone'],
    'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'elead_pro_theme_options[contact_us_phone]', array(
    'label'             => esc_html__( 'Phone Info', 'elead-pro' ),
    'section'           => 'elead_pro_contact_additional_info_section',
    'type'              => 'text',
) );


// Add email info.
$wp_customize->add_setting( 'elead_pro_theme_options[contact_us_email]', array(
    'default'           => $options['contact_us_email'],
    'sanitize_callback' => 'sanitize_email',
) );

$wp_customize->add_control( 'elead_pro_theme_options[contact_us_email]', array(
    'label'             => esc_html__( 'Address Info', 'elead-pro' ),
    'section'           => 'elead_pro_contact_additional_info_section',
    'type'              => 'email',
) );

// features custom post hr setting and control
$wp_customize->add_setting( 'elead_pro_theme_options[contact_custom_hr_line]', array(
    'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( new Elead_Pro_Customize_Horizontal_Line( $wp_customize, 'elead_pro_theme_options[contact_custom_hr_line]',
    array(
        'section'         => 'elead_pro_contact_additional_info_section',
        'type'            => 'hr'
) ) );

for ( $i = 1; $i <= 5; $i++ ) :
    // contact Section social title setting and control.
    $wp_customize->add_setting( 'elead_pro_theme_options[contact_social_link_' . $i . ']', array(
        'sanitize_callback' => 'esc_url_raw',
        'default'           => $options['contact_social_link_' . $i],
    ) );

    $wp_customize->add_control( 'elead_pro_theme_options[contact_social_link_' . $i . ']', array(
        'label'             => sprintf( esc_html__( 'Social Link %d', 'elead-pro' ), $i ),
        'section'           => 'elead_pro_contact_additional_info_section',
        'type'              => 'url',
        'input_attrs'   => array(
            'placeholder'   => esc_attr__( 'http://facebook.com', 'elead-pro' ),
            ),
    ) );
endfor;

/*
 * Map Section
 */
$wp_customize->add_section( 'elead_pro_map_section', array(
    'title'             => esc_html__( 'Map Section','elead-pro' ),
    'description'       => esc_html__( 'Map Options.', 'elead-pro' ),
    'panel'             => 'elead_pro_contact_us_panel',
) );

// Add map enable.
$wp_customize->add_setting( 'elead_pro_theme_options[contact_map_enable]', array(
    'default'           => $options['contact_map_enable'],
    'sanitize_callback' => 'elead_pro_sanitize_checkbox'
) );

$wp_customize->add_control( 'elead_pro_theme_options[contact_map_enable]', array(
    'label'             => esc_html__( 'Enable Map', 'elead-pro' ),
    'section'           => 'elead_pro_map_section',
    'type'              => 'checkbox',
) );

// map content type setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[map_content_type]', array(
    'sanitize_callback' => 'elead_pro_sanitize_select',
    'default'           => $options['map_content_type'],
) );

$wp_customize->add_control( 'elead_pro_theme_options[map_content_type]', array(
    'label'             => esc_html__( 'Content Type', 'elead-pro' ),
    'section'           => 'elead_pro_map_section',
    'type'              => 'select',
    'choices'           => array(
            'shortcode' => esc_html__( 'Shortcode', 'elead-pro' ),
            'embed'     => esc_html__( 'Embed Code', 'elead-pro' ),
        ) ,
    'active_callback'   => 'elead_pro_is_contact_map_enable',
) );

// Add Map shortcode
$wp_customize->add_setting( 'elead_pro_theme_options[map_content_shortcode]', array(
    'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'elead_pro_theme_options[map_content_shortcode]', array(
    'label'             => esc_html__( 'Input Map Shortcode', 'elead-pro' ),
    'description'       => sprintf( '%1$s %2$s WP Google Maps %3$s', esc_html__( 'Input shortcode from', 'elead-pro' ), '<a href="https://wordpress.org/plugins/wp-google-maps/" target="_blank">', '</a>' ),
    'section'           => 'elead_pro_map_section',
    'type'              => 'text',
    'active_callback'   => 'elead_pro_contact_map_content_shortcode',
) );

// Add Map embed
$wp_customize->add_setting( 'elead_pro_theme_options[map_content_embed]', array(
    'sanitize_callback' => 'elead_pro_santize_iframe_map'
) );

$wp_customize->add_control( 'elead_pro_theme_options[map_content_embed]', array(
    'label'             => esc_html__( 'Input Map Embed Code', 'elead-pro' ),
    'label'             => esc_html__( 'Notice: Please change width value to ( 100% )', 'elead-pro' ),
    'section'           => 'elead_pro_map_section',
    'type'              => 'textarea',
    'active_callback'   => 'elead_pro_contact_map_content_embed',
) );

/*
 * Contact form Section
 */
$wp_customize->add_section( 'elead_pro_contact_form_section', array(
    'title'             => esc_html__( 'Contact Form','elead-pro' ),
    'description'       => esc_html__( 'Contact Form Options.', 'elead-pro' ),
    'panel'             => 'elead_pro_contact_us_panel',
) );

// Add Contact Page contact form.
$wp_customize->add_setting( 'elead_pro_theme_options[contact_page_form]', array(
    'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'elead_pro_theme_options[contact_page_form]', array(
    'label'             => esc_html__( 'Contact Form Shortcode', 'elead-pro' ),
    'description'       => sprintf( '%1$s %2$s Contact Form 7 %3$s', esc_html__( 'Input shortcode from', 'elead-pro' ), '<a href="https://wordpress.org/plugins/contact-form-7/" target="_blank">', '</a>' ),
    'section'           => 'elead_pro_contact_form_section',
    'type'              => 'text',
) );