<?php
/**
 * Gallery Template options
 *
 * @package Theme Palace
 * @subpackage Elead Pro
 * @since Elead Pro 1.0
 */

// Add panel for Gallery Template
$wp_customize->add_panel( 'elead_pro_gallery_template_panel' , array(
    'title'      => esc_html__( 'Gallery Template','elead-pro' ),
    'description'=> esc_html__( 'Gallery Template Options', 'elead-pro' ),
    'priority'   => 150,
) );

/*
 * Naming Section
 */
$wp_customize->add_section( 'elead_pro_gallery_name_section', array(
    'title'             => esc_html__( 'Gallery Name Section','elead-pro' ),
    'description'       => esc_html__( 'Gallery Name Section Options.', 'elead-pro' ),
    'panel'             => 'elead_pro_gallery_template_panel',
) );

// Add title in naming section.
$wp_customize->add_setting( 'elead_pro_theme_options[gallery_template_title]', array(
    'sanitize_callback' => 'sanitize_text_field',
    'default'           => $options['gallery_template_title'],
) );

$wp_customize->add_control( 'elead_pro_theme_options[gallery_template_title]', array(
    'label'             => esc_html__( 'Name Section Title', 'elead-pro' ),
    'description'       => esc_html__( 'Input Place For Title', 'elead-pro' ),
    'section'           => 'elead_pro_gallery_name_section',
    'type'              => 'text',
) );

// Add subtitle in naming section.
$wp_customize->add_setting( 'elead_pro_theme_options[gallery_template_subtitle]', array(
    'sanitize_callback' => 'sanitize_text_field',
    'default'           => $options['gallery_template_subtitle'],
) );

$wp_customize->add_control( 'elead_pro_theme_options[gallery_template_subtitle]', array(
    'label'             => esc_html__( 'Name Section SubTitle', 'elead-pro' ),
    'description'       => esc_html__( 'Input Place For SubTitle', 'elead-pro' ),
    'section'           => 'elead_pro_gallery_name_section',
    'type'              => 'text',
) );

/*
 * Content Section
 */
$wp_customize->add_section( 'elead_pro_gallery_content_section', array(
    'title'             => esc_html__( 'Content Section','elead-pro' ),
    'description'       => esc_html__( 'Content Section Options.', 'elead-pro' ),
    'panel'             => 'elead_pro_gallery_template_panel',
) );

// gallery content type setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[gallery_template_type]', array(
    'sanitize_callback' => 'elead_pro_sanitize_select',
    'default'           => $options['gallery_template_type'],
) );

$wp_customize->add_control( 'elead_pro_theme_options[gallery_template_type]', array(
    'label'             => esc_html__( 'Content Type', 'elead-pro' ),
    'type'              => 'select',
    'section'           => 'elead_pro_gallery_content_section',
    'choices'           => array(
        'category'		=> esc_html__( 'Category','elead-pro' ),
    	'custom'		=> esc_html__( 'Custom','elead-pro' ),
        ) ,
) );

// gallery category setting and control
$wp_customize->add_setting( 'elead_pro_theme_options[gallery_template_category]', array(
	'sanitize_callback' => 'elead_pro_sanitize_category_list'
) );

$wp_customize->add_control( new Elead_Pro_Multiple_Category_Control( $wp_customize, 'elead_pro_theme_options[gallery_template_category]', array(
	'label'           => esc_html__( 'Select Category', 'elead-pro' ),
	'description'     => esc_html__( 'Latest posts from selected category will be shown.', 'elead-pro' ),
	'section'         => 'elead_pro_gallery_content_section',
	'type'			  => 'select-multiple-category',
	'active_callback' => 'elead_pro_gallery_template_category',
) ) );

// gallery custom setting and control
$wp_customize->add_setting( 'elead_pro_theme_options[gallery_template_custom]', array(
	'sanitize_callback' => 'elead_pro_sanitize_multiple_image'
) );

$wp_customize->add_control( new Elead_Pro_MultiImageCustomControl( $wp_customize, 'elead_pro_theme_options[gallery_template_custom]', array(
	'label'       		=> esc_html__( 'Select Images for Gallery', 'elead-pro' ),
	'description'       => esc_html__( 'Select atleast 12 images.', 'elead-pro' ),
	'section'         => 'elead_pro_gallery_content_section',
	'active_callback' => 'elead_pro_gallery_template_custom',
) ) );