<?php
/**
 * About Section options
 *
 * @package Theme Palace
 * @subpackage Elead Pro
 * @since Elead Pro 1.0
 */

$wp_customize->add_section( 'elead_pro_about', array(
	'title'             => esc_html__( 'About','elead-pro' ),
	'description'       => esc_html__( 'About Section Options.', 'elead-pro' ),
	'panel'             => 'elead_pro_sections_panel',
) );

// about section enable setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[about_enable]', array(
	'sanitize_callback'	=> 'elead_pro_sanitize_checkbox',
	'default'          	=> $options['about_enable'],
) );

$wp_customize->add_control( 'elead_pro_theme_options[about_enable]', array(
	'label'            	=> esc_html__( 'Enable About Section', 'elead-pro' ),
	'section'          	=> 'elead_pro_about',
	'type'             	=> 'checkbox',
) );

// about section content type setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[about_content_type]', array(
	'default'          	=> $options['about_content_type'],
	'sanitize_callback'	=> 'elead_pro_sanitize_select',
) );

$wp_customize->add_control( 'elead_pro_theme_options[about_content_type]', array(
	'label'            	=> esc_html__( 'About Content Type', 'elead-pro' ),
	'section'          	=> 'elead_pro_about',
	'type'             	=> 'select',
	'active_callback'	=> 'elead_pro_is_about_enable',
	'choices'			=> elead_pro_about_content_type(),
) );

// about section content type post setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[about_content_post]', array(
	'validate_callback' => 'elead_pro_validate_post_id',
	'sanitize_callback' => 'elead_pro_sanitize_single_post_id',
) );

$wp_customize->add_control( 'elead_pro_theme_options[about_content_post]', array(
	'active_callback'	=> 'elead_pro_about_content_post',
	'label'             => esc_html__( 'Input Post Id', 'elead-pro' ),
	'description'       => esc_html__( 'Please Input Valid Post Id. Simply hover post title on dashboard to see the Post ID.', 'elead-pro' ),
	'section'           => 'elead_pro_about',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'style'	=> 'width:100px',
		),
) );

// Show content type page drop-down setting and control
$wp_customize->add_setting( 'elead_pro_theme_options[about_content_page]', array(
	'sanitize_callback' => 'elead_pro_sanitize_page'
) );

$wp_customize->add_control( 'elead_pro_theme_options[about_content_page]', array(
	'label'           	=> esc_html__( 'Select Page', 'elead-pro' ),
	'section'        	=> 'elead_pro_about',
	'active_callback' 	=> 'elead_pro_about_content_page',
	'type'				=> 'dropdown-pages'
) );

// about section image type enable setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[about_image_type]', array(
	'sanitize_callback'	=> 'elead_pro_sanitize_select',
	'default'          	=> $options['about_image_type'],
) );

$wp_customize->add_control( 'elead_pro_theme_options[about_image_type]', array(
	'label'            	=> esc_html__( 'Select Image Type', 'elead-pro' ),
	'description'		=> esc_html__( 'To set multiple image from post and page option you have to add images in content of the post or page selected. At least add 3 images to get proper design.','elead-pro'),
	'section'          	=> 'elead_pro_about',
	'type'             	=> 'select',
	'active_callback'	=> 'elead_pro_is_about_enable',
	'choices'			=> array(

		'single-image'	=> esc_html__( 'Single Image','elead-pro' ),
		'multiple-image'=> esc_html__( 'Multiple Image','elead-pro' ),
	)
) );

// about section custom title setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[about_custom_title]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
	'default'          	=> $options['about_custom_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'elead_pro_theme_options[about_custom_title]', array(
	'label'            	=> esc_html__( 'Title', 'elead-pro' ),
	'section'          	=> 'elead_pro_about',
	'type'             	=> 'text',
	'active_callback'	=> 'elead_pro_about_content_custom',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'elead_pro_theme_options[about_custom_title]', array(
		'selector'            => '#about .wrapper .entry-header h2.entry-title',
		'settings'            => 'elead_pro_theme_options[about_custom_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'elead_pro_about_title',
    ) );
}

// about section custom excerpt setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[about_custom_url]', array(
	'sanitize_callback'	=> 'esc_url_raw',
	'default'          	=> $options['about_custom_url'],
) );

$wp_customize->add_control( 'elead_pro_theme_options[about_custom_url]', array(
	'label'            	=> esc_html__( 'Custom Url', 'elead-pro' ),
	'section'          	=> 'elead_pro_about',
	'type'             	=> 'url',
	'active_callback'	=> 'elead_pro_about_content_custom',
) );

// about section custom title setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[about_custom_subtitle]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
	'default'          	=> $options['about_custom_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'elead_pro_theme_options[about_custom_subtitle]', array(
	'label'            	=> esc_html__( 'Sub Title', 'elead-pro' ),
	'section'          	=> 'elead_pro_about',
	'type'             	=> 'text',
	'active_callback'	=> 'elead_pro_is_about_enable',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'elead_pro_theme_options[about_custom_subtitle]', array(
		'selector'            => '#about .wrapper .entry-header p.entry-title-desc',
		'settings'            => 'elead_pro_theme_options[about_custom_subtitle]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'elead_pro_about_sub_title',
    ) );
}

// about section custom excerpt setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[about_custom_excerpt]', array(
	'sanitize_callback'	=> 'wp_kses_post',
	'default'          	=> $options['about_custom_excerpt'],
) );

$wp_customize->add_control( 'elead_pro_theme_options[about_custom_excerpt]', array(
	'label'            	=> esc_html__( 'Description', 'elead-pro' ),
	'section'          	=> 'elead_pro_about',
	'type'             	=> 'textarea',
	'active_callback'	=> 'elead_pro_about_content_custom',
) );

for( $i=1; $i<=3; $i++ ) {

	// about section custom background image setting and control.
	$wp_customize->add_setting( 'elead_pro_theme_options[about_custom_image_'.$i.']', array(
		'default'           => $options['about_custom_image_'.$i],
		'sanitize_callback' => 'elead_pro_sanitize_image'
	) );

	$wp_customize->add_control(
		new WP_Customize_Image_Control( $wp_customize, 'elead_pro_theme_options[about_custom_image_'.$i.']',
			array(
			'label'       		=> sprintf( esc_html__( 'Custom Image %s', 'elead-pro' ),$i ),
			'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'elead-pro' ), 600, 600 ),
			'section'     		=> 'elead_pro_about',
			'active_callback'	=> 'elead_pro_about_image_type_'.$i,
	) ) );
}