<?php
/**
 * Latest News Section options
 *
 * @package Theme Palace
 * @subpackage Elead Pro
 * @since Elead Pro 1.0
 */

$wp_customize->add_section( 'elead_pro_latest_news', array(
	'title'             => esc_html__( 'Latest News & Events','elead-pro' ),
	'description'       => esc_html__( 'Latest News & Events Section Options.', 'elead-pro' ),
	'panel'             => 'elead_pro_sections_panel',
) );

// latest news Section enable setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[latest_news_enable]', array(
	'sanitize_callback'	=> 'elead_pro_sanitize_checkbox',
	'default'          	=> $options['latest_news_enable'],
) );

$wp_customize->add_control( 'elead_pro_theme_options[latest_news_enable]', array(
	'label'            	=> esc_html__( 'Enable News & Events Section', 'elead-pro' ),
	'section'          	=> 'elead_pro_latest_news',
	'type'             	=> 'checkbox',
) );

// latest news Section title setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[latest_news_title]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
	'default'          	=> $options['latest_news_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'elead_pro_theme_options[latest_news_title]', array(
	'label'            	=> esc_html__( 'Title', 'elead-pro' ),
	'section'          	=> 'elead_pro_latest_news',
	'type'             	=> 'text',
	'active_callback'	=> 'elead_pro_is_latest_news_enable',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'elead_pro_theme_options[latest_news_title]', array(
		'selector'            => '#news-events .wrapper .page-header h2',
		'settings'            => 'elead_pro_theme_options[latest_news_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'elead_pro_latest_news_title',
    ) );
}

// latest news Section subtitle setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[latest_news_subtitle]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
	'default'          	=> $options['latest_news_subtitle'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'elead_pro_theme_options[latest_news_subtitle]', array(
	'label'            	=> esc_html__( 'Sub Title', 'elead-pro' ),
	'section'          	=> 'elead_pro_latest_news',
	'type'             	=> 'text',
	'active_callback'	=> 'elead_pro_is_latest_news_enable',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'elead_pro_theme_options[latest_news_subtitle]', array(
		'selector'            => '#news-events .wrapper .page-header h3',
		'settings'            => 'elead_pro_theme_options[latest_news_subtitle]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'elead_pro_latest_news_sub_title',
    ) );
}

// latest news Section content type setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[latest_news_content_type]', array(
	'default'          	=> $options['latest_news_content_type'],
	'sanitize_callback'	=> 'elead_pro_sanitize_select',
) );

$wp_customize->add_control( 'elead_pro_theme_options[latest_news_content_type]', array(
	'label'            	=> esc_html__( 'Content Type', 'elead-pro' ),
	'section'          	=> 'elead_pro_latest_news',
	'type'             	=> 'select',
	'active_callback'	=> 'elead_pro_is_latest_news_enable',
	'choices'			=> elead_pro_latest_news_content_type(),
) );

// latest news Section content type category setting and control
$wp_customize->add_setting( 'elead_pro_theme_options[latest_news_content_category]', array(
	'sanitize_callback' => 'elead_pro_sanitize_single_category'
) );

$wp_customize->add_control( new Elead_Pro_Dropdown_Single_Category_Control( $wp_customize, 'elead_pro_theme_options[latest_news_content_category]', array(
	'label'           => esc_html__( 'Select Category', 'elead-pro' ),
	'description'     => esc_html__( 'Latest posts from selected category will be shown.', 'elead-pro' ),
	'section'         => 'elead_pro_latest_news',
	'type'			  => 'dropdown-category',
	'active_callback' => 'elead_pro_latest_news_content_category',
) ) );

// latest news Section content type event category setting and control
$wp_customize->add_setting( 'elead_pro_theme_options[latest_news_content_event_category]', array(
	'sanitize_callback' => 'absint'
) );

$wp_customize->add_control( new Elead_Pro_Dropdown_Single_Category_Control( $wp_customize, 'elead_pro_theme_options[latest_news_content_event_category]', array(
	'label'           => esc_html__( 'Select Category', 'elead-pro' ),
	'description'     => esc_html__( 'Latest events from selected category will be shown.', 'elead-pro' ),
	'section'         => 'elead_pro_latest_news',
	'taxonomy'		  => 'tp-event-category',
	'type'			  => 'dropdown-category',
	'active_callback' => 'elead_pro_latest_news_content_event_category',
) ) );

// Latest News left side note
$wp_customize->add_setting( 'elead_pro_theme_options[latest_news_recent_event]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
) );

$wp_customize->add_control( new Elead_Pro_Note_Control( $wp_customize, 'elead_pro_theme_options[latest_news_recent_event]', array(
	'label'       => esc_html__( 'Latest events will be shown.', 'elead-pro' ),
	'section'         	=> 'elead_pro_latest_news',
	'type'            	=> 'description',
	'active_callback' 	=> 'elead_pro_latest_news_content_recent_event',
) ) );

// Latest News left side note 
$wp_customize->add_setting( 'elead_pro_theme_options[latest_news_recent_post]', array(
	'sanitize_callback'	=> 'sanitize_text_field',
) );

$wp_customize->add_control( new Elead_Pro_Note_Control( $wp_customize, 'elead_pro_theme_options[latest_news_recent_post]', array(
	'label'       => esc_html__( 'Latest posts will be shown.', 'elead-pro' ),
	'section'         	=> 'elead_pro_latest_news',
	'type'            	=> 'description',
	'active_callback' 	=> 'elead_pro_latest_news_content_recent_post',
) ) );


// latest news post hr setting and control
$wp_customize->add_setting( 'elead_pro_theme_options[latest_news_hr]', array(
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( new Elead_Pro_Customize_Horizontal_Line( $wp_customize, 'elead_pro_theme_options[latest_news_hr]',
	array(
		'section'         => 'elead_pro_latest_news',
		'active_callback' => 'elead_pro_is_latest_news_enable',
		'type'			  => 'hr'
) ) );

// team section button label setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[latest_news_custom_btn_label]', array(
	'default'           => $options['latest_news_custom_btn_label'],
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'elead_pro_theme_options[latest_news_custom_btn_label]', array(
	'active_callback'	=> 'elead_pro_latest_news_content_category_disable',
	'label'             => esc_html__( 'Custom button label', 'elead-pro' ),
	'section'           => 'elead_pro_latest_news',
	'type'				=> 'text'
) );

// team section button label url setting and control.
$wp_customize->add_setting( 'elead_pro_theme_options[latest_news_custom_btn_url]', array(
	'default'           => $options['latest_news_custom_btn_url'],
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( 'elead_pro_theme_options[latest_news_custom_btn_url]', array(
	'active_callback'	=> 'elead_pro_latest_news_content_category_disable',
	'label'             => esc_html__( 'Custom button url', 'elead-pro' ),
	'section'           => 'elead_pro_latest_news',
	'type'				=> 'text'
) );