<?php
/**
 * elead_pro options
 *
 * @package Theme Palace
 * @subpackage Elead Pro
 * @since Elead Pro 1.0
 */

if ( ! function_exists( 'elead_pro_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function elead_pro_typography_options() {

        $choices = array(
            'default'         => esc_html__( 'Default', 'elead-pro' ),
            'header-font-1'   => esc_html__( 'Rajdhani', 'elead-pro' ),
            'header-font-2'   => esc_html__( 'Cherry Swash', 'elead-pro' ),
            'header-font-3'   => esc_html__( 'Philosopher', 'elead-pro' ),
            'header-font-4'   => esc_html__( 'Slabo 27px', 'elead-pro' ),
            'header-font-5'   => esc_html__( 'Dosis', 'elead-pro' ),
        );
        $output = apply_filters( 'elead_pro_typography_options', $choices );
        if ( ! empty( $output ) ) {
          ksort( $output );
        }
        return $output;

    }
endif;

if ( ! function_exists( 'elead_pro_body_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function elead_pro_body_typography_options(){
        $choices = array(
            'default'         => esc_html__( 'Default', 'elead-pro' ),
            'body-font-1'     => esc_html__( 'News Cycle', 'elead-pro' ),
            'body-font-2'     => esc_html__( 'Pontano Sans', 'elead-pro' ),
            'body-font-3'     => esc_html__( 'Gudea', 'elead-pro' ),
            'body-font-4'     => esc_html__( 'Quattrocento', 'elead-pro' ),
            'body-font-5'     => esc_html__( 'Khand', 'elead-pro' ),
        );

        $output = apply_filters( 'elead_pro_body_typography_options', $choices );
        if ( ! empty( $output ) ) {
          ksort( $output );
        }

        return $output;
    }
endif;


if ( ! function_exists( 'elead_pro_site_layout' ) ) :
    /**
     * Site Layout
     * @return array site layout options
     */
    function elead_pro_site_layout() {
        $elead_pro_site_layout = array(
            'wide'  => esc_html__( 'Wide', 'elead-pro' ),
            'boxed' => esc_html__( 'Boxed', 'elead-pro' ),
        );

        $output = apply_filters( 'elead_pro_site_layout', $elead_pro_site_layout );

        return $output;
    }
endif;


if ( ! function_exists( 'elead_pro_sidebar_position' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function elead_pro_sidebar_position() {
        $elead_pro_sidebar_position = array(
            'right-sidebar' => esc_html__( 'Right', 'elead-pro' ),
            'left-sidebar'  => esc_html__( 'Left', 'elead-pro' ),
            'no-sidebar'    => esc_html__( 'No Sidebar', 'elead-pro' ),
        );

        $output = apply_filters( 'elead_pro_sidebar_position', $elead_pro_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'elead_pro_selected_sidebar' ) ) :
    /**
     * Sidebar selected
     * @return array Sidbar selected
     */
    function elead_pro_selected_sidebar() {
        $elead_pro_selected_sidebar = array(
            'sidebar-1'                            => esc_html__( 'Primary Sidebar', 'elead-pro' ),
            'elead-pro-optional-sidebar'    => esc_html__( 'Optional Sidebar 1', 'elead-pro' ),
            'elead-pro-optional-sidebar-2'  => esc_html__( 'Optional Sidebar 2', 'elead-pro' ),
            'elead-pro-optional-sidebar-3'  => esc_html__( 'Optional Sidebar 3', 'elead-pro' ),
        );

        $output = apply_filters( 'elead_pro_selected_sidebar', $elead_pro_selected_sidebar );

        return $output;
    }
endif;


if ( ! function_exists( 'elead_pro_header_image' ) ) :
    /**
     * Header image options
     * @return array Header image options
     */
    function elead_pro_header_image() {
        $elead_pro_header_image = array(
            'show-both' => esc_html__( 'Show Both( Featured and Header Image )', 'elead-pro' ),
            'enable'    => esc_html__( 'Enable( Featured Image )', 'elead-pro' ),
            'default'   => esc_html__( 'Default ( Customizer Header Image )', 'elead-pro' ),
        );

        $output = apply_filters( 'elead_pro_header_image', $elead_pro_header_image );

        return $output;
    }
endif;

if ( ! function_exists( 'elead_pro_theme_color' ) ) :
    /**
     * Pagination
     * @return array site pagination options
     */
    function elead_pro_theme_color() {
        $elead_pro_theme_color = array(
            'red'       => esc_html__( 'Red', 'elead-pro' ),
            'blue'      => esc_html__( 'Blue', 'elead-pro' ),
            'green'     => esc_html__( 'Green', 'elead-pro' ),
            'light-blue'=> esc_html__( 'Light Blue', 'elead-pro' ),
            'orange'    => esc_html__( 'Orange', 'elead-pro' ),
            'purple'    => esc_html__( 'Purple', 'elead-pro' ),
        );
        $output = apply_filters( 'elead_pro_theme_color', $elead_pro_theme_color );
        return $output;
    }
endif;

if ( ! function_exists( 'elead_pro_pagination_options' ) ) :
    /**
     * Pagination
     * @return array site pagination options
     */
    function elead_pro_pagination_options() {
        $elead_pro_pagination_options = array(
            'numeric'  => esc_html__( 'Numeric', 'elead-pro' ),
            'default'  => esc_html__( 'Default(Older/Newer)', 'elead-pro' ),
            'infinite'  => esc_html__( 'Infinite Scroll', 'elead-pro' ),
        );

        $output = apply_filters( 'elead_pro_pagination_options', $elead_pro_pagination_options );

        return $output;
    }
endif;

if ( ! function_exists( 'elead_pro_headline_options' ) ) :
    /**
     * Headline
     * @return array site headline options
     */
    function elead_pro_headline_options() {
        $elead_pro_headline_options = array(
            'demo'      => esc_html__( 'Demo', 'elead-pro' ),
            'post'      => esc_html__( 'Post', 'elead-pro' ),
            'category'  => esc_html__( 'Category', 'elead-pro' ),
        );

        $output = apply_filters( 'elead_pro_headline_options', $elead_pro_headline_options );

        return $output;
    }
endif;

if ( ! function_exists( 'elead_pro_slider_effect' ) ) :
    /**
     * Slider effects
     * @return array Slider effects
     */
    function elead_pro_slider_effect() {
      $elead_pro_slider_effect = array(
            'fade'                                        => esc_html__( 'Fade', 'elead-pro' ),
            'cubic-bezier(0.250, 0.250, 0.750, 0.750)'    => esc_html__( 'Linear', 'elead-pro' ),
            'cubic-bezier(0.250, 0.100, 0.250, 1.000)'    => esc_html__( 'Ease', 'elead-pro' ),
            'cubic-bezier(0.950, 0.050, 0.795, 0.035)'    => esc_html__( 'Cubic', 'elead-pro' ),
            'cubic-bezier(0.600, -0.280, 0.735, 0.045)'   => esc_html__( 'Ease In Back', 'elead-pro' ),
            'cubic-bezier(0.785, 0.135, 0.150, 0.860)'    => esc_html__( 'EaseInOutCirc', 'elead-pro' ),
            'cubic-bezier(0.680, -0.550, 0.265, 1.550)'   => esc_html__( 'EaseInOutBack', 'elead-pro' ),
        );

        $output =  apply_filters( 'elead_pro_slider_effect', $elead_pro_slider_effect );

        return $output;
    }
endif;

if ( ! function_exists( 'elead_pro_slider_transition_duration' ) ) :
    /**
     * Slider transition duration
     * @return array Slider transition duration
     */
    function elead_pro_slider_transition_duration() {
        $elead_pro_slider_transition_duration = array(
            '1000'    => esc_html__( '1 sec', 'elead-pro' ),
            '2000'    => esc_html__( '2 sec', 'elead-pro' ),
            '3000'    => esc_html__( '3 sec', 'elead-pro' ),
            '4000'    => esc_html__( '4 sec', 'elead-pro' ),
            '5000'    => esc_html__( '5 sec', 'elead-pro' ),
        );

        $output =  apply_filters( 'elead_pro_slider_transition_duration', $elead_pro_slider_transition_duration );

        return $output;
    }
endif;

if ( ! function_exists( 'elead_pro_common_content_type' ) ) :
    /**
     * Common content types
     * @return array Content types
     */
    function elead_pro_common_content_type() {
        $elead_pro_content_type = array(
            'demo'      => esc_html__( 'Demo', 'elead-pro' ),
            'page'      => esc_html__( 'Page', 'elead-pro' ),
            'post'      => esc_html__( 'Post', 'elead-pro' ),
            'custom'    => esc_html__( 'Custom', 'elead-pro' ),
            'category'  => esc_html__( 'Category', 'elead-pro' ),
        ); 

        $output = apply_filters( 'elead_pro_common_content_type', $elead_pro_content_type );

        return $output;
    }
endif;


if ( ! function_exists( 'elead_pro_about_content_type' ) ) :
    /**
     * Common content types
     * @return array Content types
     */
    function elead_pro_about_content_type() {
        $elead_pro_content_type = array(
            'demo'      => esc_html__( 'Demo', 'elead-pro' ),
            'page'      => esc_html__( 'Page', 'elead-pro' ),
            'post'      => esc_html__( 'Post', 'elead-pro' ),
            'custom'    => esc_html__( 'Custom', 'elead-pro' ),
        ); 

        $output = apply_filters( 'elead_pro_about_content_type', $elead_pro_content_type );

        return $output;
    }
endif;

if ( ! function_exists( 'elead_pro_courses_content_type' ) ) :
    /**
     * courses content types
     * @return array Content types
     */
    function elead_pro_courses_content_type() {
        $elead_pro_content_type = array(
            'demo'      => esc_html__( 'Demo', 'elead-pro' ),
            'post'      => esc_html__( 'Post', 'elead-pro' ),
            'custom'    => esc_html__( 'Custom', 'elead-pro' ),
            'category'  => esc_html__( 'Category', 'elead-pro' ),
        ); 
        if ( class_exists( 'TP_Education' ) ) {
            $elead_pro_content_type = array_merge( $elead_pro_content_type, array(
                'course'            => esc_html__( 'Course', 'elead-pro' ),
                'course-category'   => esc_html__( 'Courses Category', 'elead-pro' ),
                ) );
        }

        $output = apply_filters( 'elead_pro_courses_content_type', $elead_pro_content_type );

        return $output;
    }
endif;

if ( ! function_exists( 'elead_pro_latest_news_content_type' ) ) :
    /**
     * latest news content types
     * @return array Content types
     */
    function elead_pro_latest_news_content_type() {
        $elead_pro_content_type = array(
            'demo'          => esc_html__( 'Demo', 'elead-pro' ),
            'recent-post'   => esc_html__( 'Recent Posts', 'elead-pro' ),
            'category'      => esc_html__( 'Category', 'elead-pro' ),
        ); 
        if ( class_exists( 'TP_Education' ) ) {
            $elead_pro_content_type = array_merge( $elead_pro_content_type, array(
                'recent-event'      => esc_html__( 'Recent Events', 'elead-pro' ),
                'event-category'    => esc_html__( 'Event Category', 'elead-pro' ),
                ) );
        }

        $output = apply_filters( 'elead_pro_latest_news_content_type', $elead_pro_content_type );

        return $output;
    }
endif;

if ( ! function_exists( 'elead_pro_team_content_type' ) ) :
    /**
     * team content types
     * @return array Content types
     */
    function elead_pro_team_content_type() {
        $elead_pro_content_type = array(
            'demo'      => esc_html__( 'Demo', 'elead-pro' ),
            'post'      => esc_html__( 'Post', 'elead-pro' ),
            'custom'    => esc_html__( 'Custom', 'elead-pro' ),
            'category'  => esc_html__( 'Category', 'elead-pro' ),
        ); 
        if ( class_exists( 'TP_Education' ) ) {
            $elead_pro_content_type = array_merge( $elead_pro_content_type, array(
                'team'            => esc_html__( 'Team', 'elead-pro' ),
                'team-category'   => esc_html__( 'Team Category', 'elead-pro' ),
                ) );
        }

        $output = apply_filters( 'elead_pro_team_content_type', $elead_pro_content_type );

        return $output;
    }
endif;


if ( ! function_exists( 'elead_pro_gallery_content_type' ) ) :
    /**
     * Common content types
     * @return array Content types
     */
    function elead_pro_gallery_content_type() {
        $elead_pro_content_type = array(
            'demo'      => esc_html__( 'Demo', 'elead-pro' ),
            'post'      => esc_html__( 'Post', 'elead-pro' ),
            'category'  => esc_html__( 'Category', 'elead-pro' ),
            'custom'  => esc_html__( 'Custom', 'elead-pro' ),
        ); 

        $output = apply_filters( 'elead_pro_gallery_content_type', $elead_pro_content_type );

        return $output;
    }
endif;

if ( ! function_exists( 'elead_pro_testimonial_content_type' ) ) :
    /**
     * testimonial content types
     * @return array Content types
     */
    function elead_pro_testimonial_content_type() {
        $elead_pro_content_type = array(
            'demo'      => esc_html__( 'Demo', 'elead-pro' ),
            'post'      => esc_html__( 'Post', 'elead-pro' ),
            'custom'    => esc_html__( 'Custom', 'elead-pro' ),
            'category'  => esc_html__( 'Category', 'elead-pro' ),
        ); 
        if ( class_exists( 'TP_Education' ) ) {
            $elead_pro_content_type = array_merge( $elead_pro_content_type, array(
                'testimonial'           => esc_html__( 'Testimonial', 'elead-pro' ),
                'recent-testimonial'    => esc_html__( 'Recent Testimonial', 'elead-pro' ),
                ) );
        }

        $output = apply_filters( 'elead_pro_testimonial_content_type', $elead_pro_content_type );

        return $output;
    }
endif;

/* CUSTOM TEMPLATE */

if ( ! function_exists( 'elead_pro_study_abroad_destination' ) ) :
    /**
     * Common content types
     * @return array Content types
     */
    function elead_pro_study_abroad_destination() {
        $elead_pro_content_type = array(
            'post'      => esc_html__( 'Post', 'elead-pro' ),
            'category'  => esc_html__( 'Category', 'elead-pro' ),
            'custom'    => esc_html__( 'Custom', 'elead-pro' ),
        ); 
        if ( class_exists( 'TP_Education' ) ) {
            $elead_pro_content_type = array_merge( $elead_pro_content_type, array(
                'excursion'             => esc_html__( 'Excursion', 'elead-pro' ),
                'excursion-category'    => esc_html__( 'Excursion Category', 'elead-pro' ),
                ) );
        }

        $output = apply_filters( 'elead_pro_study_abroad_destination', $elead_pro_content_type );

        return $output;
    }
endif;

if ( ! function_exists( 'elead_pro_study_guide' ) ) :
    /**
     * Common content types
     * @return array Content types
     */
    function elead_pro_study_guide() {
        $elead_pro_content_type = array(
            'post'      => esc_html__( 'Post', 'elead-pro' ),
            'category'  => esc_html__( 'Category', 'elead-pro' ),
            'custom'    => esc_html__( 'Custom', 'elead-pro' ),
        ); 

        $output = apply_filters( 'elead_pro_study_guide', $elead_pro_content_type );

        return $output;
    }
endif;

if ( ! function_exists( 'elead_pro_goal' ) ) :
    /**
     * goal content types
     * @return array Content types
     */
    function elead_pro_goal() {
        $elead_pro_content_type = array(
            'post'      => esc_html__( 'Post', 'elead-pro' ),
            'page'      => esc_html__( 'Page', 'elead-pro' ),
            'custom'    => esc_html__( 'Custom', 'elead-pro' ),
        ); 

        $output = apply_filters( 'elead_pro_goal', $elead_pro_content_type );

        return $output;
    }
endif;

if ( ! function_exists( 'elead_pro_quality_service' ) ) :
    /**
     * quality service content types
     * @return array Content types
     */
    function elead_pro_quality_service() {
        $elead_pro_content_type = array(
            'post'      => esc_html__( 'Post', 'elead-pro' ),
            'category'  => esc_html__( 'Category', 'elead-pro' ),
            'custom'    => esc_html__( 'Custom', 'elead-pro' ),
        ); 

        $output = apply_filters( 'elead_pro_quality_service', $elead_pro_content_type );

        return $output;
    }
endif;

if ( ! function_exists( 'elead_pro_message' ) ) :
    /**
     * message content types
     * @return array Content types
     */
    function elead_pro_message() {
        $elead_pro_content_type = array(
            'post'      => esc_html__( 'Post', 'elead-pro' ),
            'page'      => esc_html__( 'Page', 'elead-pro' ),
            'custom'    => esc_html__( 'Custom', 'elead-pro' ),
        ); 

        $output = apply_filters( 'elead_pro_message', $elead_pro_content_type );

        return $output;
    }
endif;

if ( ! function_exists( 'elead_pro_aboutteam_content_type' ) ) :
    /**
     * team content types
     * @return array Content types
     */
    function elead_pro_aboutteam_content_type() {
        $elead_pro_content_type = array(
            'post'      => esc_html__( 'Post', 'elead-pro' ),
            'custom'    => esc_html__( 'Custom', 'elead-pro' ),
            'category'  => esc_html__( 'Category', 'elead-pro' ),
        ); 
        if ( class_exists( 'TP_Education' ) ) {
            $elead_pro_content_type = array_merge( $elead_pro_content_type, array(
                'team'            => esc_html__( 'Team', 'elead-pro' ),
                'team-category'   => esc_html__( 'Team Category', 'elead-pro' ),
                ) );
        }

        $output = apply_filters( 'elead_pro_aboutteam_content_type', $elead_pro_content_type );

        return $output;
    }
endif;